==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/SES/UpdateConfigurationSetTrackingOptions.pm <==

package Paws::SES::UpdateConfigurationSetTrackingOptions;
  use Moose;
  has ConfigurationSetName => (is => 'ro', isa => 'Str', required => 1);
  has TrackingOptions => (is => 'ro', isa => 'Paws::SES::TrackingOptions', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'UpdateConfigurationSetTrackingOptions');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SES::UpdateConfigurationSetTrackingOptionsResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'UpdateConfigurationSetTrackingOptionsResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SES::UpdateConfigurationSetTrackingOptions - Arguments for method UpdateConfigurationSetTrackingOptions on Paws::SES

=head1 DESCRIPTION

This class represents the parameters used for calling the method UpdateConfigurationSetTrackingOptions on the 
Amazon Simple Email Service service. Use the attributes of this class
as arguments to method UpdateConfigurationSetTrackingOptions.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to UpdateConfigurationSetTrackingOptions.

As an example:

  $service_obj->UpdateConfigurationSetTrackingOptions(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> ConfigurationSetName => Str

The name of the configuration set for which you want to update the
custom tracking domain.



=head2 B<REQUIRED> TrackingOptions => L<Paws::SES::TrackingOptions>






=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method UpdateConfigurationSetTrackingOptions in L<Paws::SES>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.45.tar.gz: Paws-0.45/lib/Paws/SES/UpdateConfigurationSetTrackingOptions.pm <==

package Paws::SES::UpdateConfigurationSetTrackingOptions;
  use Moose;
  has ConfigurationSetName => (is => 'ro', isa => 'Str', required => 1);
  has TrackingOptions => (is => 'ro', isa => 'Paws::SES::TrackingOptions', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'UpdateConfigurationSetTrackingOptions');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SES::UpdateConfigurationSetTrackingOptionsResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'UpdateConfigurationSetTrackingOptionsResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SES::UpdateConfigurationSetTrackingOptions - Arguments for method UpdateConfigurationSetTrackingOptions on L<Paws::SES>

=head1 DESCRIPTION

This class represents the parameters used for calling the method UpdateConfigurationSetTrackingOptions on the
L<Amazon Simple Email Service|Paws::SES> service. Use the attributes of this class
as arguments to method UpdateConfigurationSetTrackingOptions.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to UpdateConfigurationSetTrackingOptions.

=head1 SYNOPSIS

    my $email = Paws->service('SES');
    my $UpdateConfigurationSetTrackingOptionsResponse =
      $email->UpdateConfigurationSetTrackingOptions(
      ConfigurationSetName => 'MyConfigurationSetName',
      TrackingOptions      => {
        CustomRedirectDomain => 'MyCustomRedirectDomain',    # OPTIONAL
      },

      );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/email/UpdateConfigurationSetTrackingOptions>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ConfigurationSetName => Str

The name of the configuration set for which you want to update the
custom tracking domain.



=head2 B<REQUIRED> TrackingOptions => L<Paws::SES::TrackingOptions>






=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method UpdateConfigurationSetTrackingOptions in L<Paws::SES>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
